@@ -415,7 +415,7 @@ class MvEdStats(object):
 
 
 class SourceFilenameError(Exception):
-    pass
+    """An added filename is invalid according to `is_valid_name`"""
 
 
 class FileSet(object):
@@ -909,7 +909,6 @@ class MvEd(object):
         self.files = []
 
         self.stats = MvEdStats()
-        self.dir_levels = 1
         self.calculated = False
         self.autodelete_dirs = True
         self.have_error = False
@@ -920,8 +919,8 @@ class MvEd(object):
         self.have_error = True
         log.error("%s", e)
 
-    def add_files(self, *files):
-        self.sourceset.add_files(files, self.dir_levels)
+    def add_files(self, *files, levels=0):
+        self.sourceset.add_files(files, levels)
 
     def add_files_raw(self, files):
         self.sourceset.add_files_raw(files)
@@ -943,7 +942,8 @@ class MvEd(object):
     def reset(self):
         for f in self.files:
             f.reset()
-        self.calculated = True
+        del self.changeset
+        self.calculated = False
         self.stats.reset(files=False)
 
     def calculate_changes(self):
@@ -1078,12 +1078,11 @@ def main():
 
     from mved.fscache import FsCache
     ed = MvEd(FsCache(RealFs()))
-    ed.dir_levels = args.levels
     try:
         if not args.files:
-            ed.add_files(".")
+            ed.add_files(".", levels=args.levels)
         else:
-            ed.add_files(*args.files)
+            ed.add_files(*args.files, levels=args.levels)
     except SourceFilenameError as e:
         print(f"invalid filename: {e}", file=sys.stderr)
         return 1
